---
 drivers/md/dm-table.c |   28 ++++++++++++++--------------
 1 file changed, 14 insertions(+), 14 deletions(-)

Index: linux-2.6.30-rc7/drivers/md/dm-table.c
===================================================================
--- linux-2.6.30-rc7.orig/drivers/md/dm-table.c
+++ linux-2.6.30-rc7/drivers/md/dm-table.c
@@ -721,22 +721,22 @@ static void check_for_valid_limits(struc
 
 /*
  * Impose necessary and sufficient conditions on a devices's table such
- * that any incoming bio which respects its logical_block_size can be
+ * that any incoming bio which respects its hardsect_size can be
  * processed successfully.  If it falls across the boundary between
  * two or more targets, the size of each piece it gets split into must
- * be compatible with the logical_block_size of the target processing it.
+ * be compatible with the hardsect_size of the target processing it.
  */
-static int validate_hardware_logical_block_alignment(struct dm_table *table)
+static int validate_hardsect_alignment(struct dm_table *table)
 {
 	/*
-	 * This function uses arithmetic modulo the logical_block_size
+	 * This function uses arithmetic modulo the hardsect_size
 	 * (in units of 512-byte sectors).
 	 */
-	unsigned short device_logical_block_size_sects =
-		table->limits.logical_block_size >> SECTOR_SHIFT;
+	unsigned short device_hardsect_size_sects =
+			    table->limits.hardsect_size >> SECTOR_SHIFT;
 
 	/*
-	 * Offset of the start of the next table entry, mod logical_block_size.
+	 * Offset of the start of the next table entry, mod hardsect_size.
 	 */
 	unsigned short next_target_start = 0;
 
@@ -757,27 +757,27 @@ static int validate_hardware_logical_blo
 
 		/*
 		 * If the remaining sectors fall entirely within this
-		 * table entry are they compatible with its logical_block_size?
+		 * table entry are they compatible with its hardsect_size?
 		 */
 		if (remaining < ti->len &&
-		    remaining & ((ti->limits.logical_block_size >>
+		    remaining & ((ti->limits.hardsect_size >>
 				  SECTOR_SHIFT) - 1))
 			break;	/* Error */
 
 		next_target_start =
 		    (unsigned short) ((next_target_start + ti->len) &
-				      (device_logical_block_size_sects - 1));
+				      (device_hardsect_size_sects - 1));
 		remaining = next_target_start ?
-		    device_logical_block_size_sects - next_target_start : 0;
+		    device_hardsect_size_sects - next_target_start : 0;
 	}
 
 	if (remaining) {
 		DMWARN("%s: table line %u (start sect %llu len %llu) "
-		       "not aligned to hardware logical block size %hu",
+		       "not aligned to hardware sector size %hu",
 		       dm_device_name(table->md), i,
 		       (unsigned long long) ti->begin,
 		       (unsigned long long) ti->len,
-		       table->limits.logical_block_size);
+		       table->limits.hardsect_size);
 		return -EINVAL;
 	}
 
@@ -883,7 +883,7 @@ int dm_table_complete(struct dm_table *t
 
 	check_for_valid_limits(&t->limits);
 
-	r = validate_hardware_logical_block_alignment(t);
+	r = validate_hardsect_alignment(t);
 	if (r)
 		return r;
 
